@@ -1,6 +1,7 @@
 #pragma once
 
 #include <arpa/inet.h>
+#include <pcap.h>
 
 #include <ostream>
 
@@ -11,3 +12,5 @@ std::ostream& operator<<(std::ostream& os, in6_addr const& v);
 std::ostream& operator<<(std::ostream& os, sockaddr_in const& v);
 
 std::ostream& operator<<(std::ostream& os, sockaddr_in6 const& v);
+
+std::ostream& operator<<(std::ostream& os, pcap_stat const& v);
