@@ -3,10 +3,17 @@
 #include <arpa/inet.h>
 #include <tins/tins.h>
 
+#include <set>
 #include <string>
 
 namespace caracal::Utilities {
 
+[[nodiscard]] std::set<Tins::IPv4Address> all_ipv4_for(
+    const Tins::NetworkInterface& interface);
+
+[[nodiscard]] std::set<Tins::IPv6Address> all_ipv6_for(
+    const Tins::NetworkInterface& interface);
+
 [[nodiscard]] Tins::IPv4Address source_ipv4_for(
     const Tins::NetworkInterface& interface);
 
